@@ -5,9 +5,11 @@ use warnings;
 use 5.008001;
 use base qw(Alien::Base);
 
-our $VERSION = '2.01'; # VERSION
+our $VERSION = '2.02'; # VERSION
 # ABSTRACT: Build and install libyaml, a C-based YAML parser and emitter
 
+
+
 1;
 
 __END__
@@ -22,21 +24,42 @@ Alien::LibYAML - Build and install libyaml, a C-based YAML parser and emitter
 
 =head1 VERSION
 
-version 2.01
+version 2.02
 
 =head1 SYNOPSIS
 
-In your C<Build.PL>:
+In your Build.PL:
 
-    use Alien::LibYAML;
-    use Module::Build;
-    
-    Module::Build->new(
-      ...
-      extra_compiler_flags => Alien::LibYAML->cflags,
-      extra_linker_flags   => Alien::LibYAML->libs,
-      ...
-    )->create_build_script;
+ use Module::Build;
+ use Alien::LibYAML;
+ my $builder = Module::Build->new(
+   ...
+   configure_requires => {
+     'Alien::LibYAML' => '0',
+     ...
+   },
+   extra_compiler_flags => Alien::LibYAML->cflags,
+   extra_linker_flags   => Alien::LibYAML->libs,
+   ...
+ );
+ 
+ $build->create_build_script;
+
+In your Makefile.PL:
+
+ use ExtUtils::MakeMaker;
+ use Config;
+ use Alien::LibYAML;
+ 
+ WriteMakefile(
+   ...
+   CONFIGURE_REQUIRES => {
+     'Alien::LibYAML' => '0',
+   },
+   CCFLAGS => Alien::LibYAML->cflags . " $Config{ccflags}",
+   LIBS    => [ Alien::LibYAML->libs ],
+   ...
+ );
 
 =head1 DESCRIPTION
 
@@ -60,23 +83,15 @@ Simonov. Both libyaml and this distribution are released under the terms of the
 B<MIT License> and may be modified and/or redistributed under the same or any
 compatible license.
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-=over 4
+Original author: Richard Simões (RSIMOES)
 
-=item *
-
-Richard Simões <rsimoes AT cpan DOT org>
-
-=item *
-
-Graham Ollis <plicease@cpan.org>
-
-=back
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Richard Simões.
+This software is Copyright (c) 2013-2018 by Richard Simões.
 
 This is free software, licensed under:
 
